#!/bin/perl5.8

=head1 Name

NFRJ --- Subroutines for NFRJ  data

	Created: 2008-04-27
	Updated: 2008-04-27
	Updated: 2008-05-06: Functions Era_year Era_year_m Era_year_t Era_year_s added

=head1 Usage

use NFRJ

=cut

package NFRJ;

use Dredu;

use Exporter ();
@ISA = qw(Dredu Exporter);
@EXPORT = qw( Era_year Era_year_m Era_year_t Era_year_s Age7);
@EXPORT_OK = qw( );


# ************************************
#  Declare Constants and Global variables
# ************************************

=head1 Global Variables

=head2 

=cut


# ************************************
# Methods
# ************************************

=head1 Exported Subroutines

=head2 Era_year( $e, $y ) - Convert year from Japanese imperial era to A.D.
		Argument: $e : 1 for Taisyou; 2 for Syouwa; 3 for Heisei

=cut

sub Era_year {
	my ( $e, $y ) = @_ ;
	return $e if miss($e);
	return $y if miss($y);
	if( 0==$e ){
		warn( "Wrong year: M $y\n" )  if $y<1 or 45<$y ;
		return $y + 1867;
	}
	if( 1==$e ){
		warn( "Wrong year: T $y\n" )  if $y<1 or 15<$y ;
		return $y + 1911;
	}
	if( 2==$e ){
		warn( "Wrong year: S $y\n" )  if $y<1 or 64<$y ;
		return $y + 1925;
	}
	if( 3==$e ){
		warn( "Wrong year: H $y\n" )  if $y<1  ;
		return $y + 1988;
	}

	warn( "Wrong era-year: $e-$y\n" );
}

sub Era_year_m {
	my ( $x, $y ) =@_ ;
	$x *= 100  if 0<$x && $x<5;
	my $e = Recode( $x , 
		100=>0,	# Meiji
		200=>1,	# Taisho
		300=>2,	# Showa
		400=>3,	# Heisei
	);

	Era_year( $e, $y );
}

sub Era_year_t {
	my ( $x, $y );	my ( $x, $y ) =@_ ;
	$x *= 100  if 0<$x && $x<5;
	my $e = Recode( $x , 
		100=>1,	# Taisho
		200=>2,	# Showa
		300=>3,	# Heisei
	);
	Era_year( $e, $y );
}

sub Era_year_s {
	my ( $x, $y );	my ( $x, $y ) =@_ ;
	$x *= 100  if 0<$x && $x<5;
	my $e = Recode( $x , 
		100=>2,	# Showa
		200=>3,	# Heisei
	);
	Era_year( $e, $y );
}

=head2 Age7( $a ) - Convert age to ten-year interval
		Argument: int $a
		Return value: 3 for 0-7, 12 for 8-17, ...; $a for $a>78 or missing value

=cut

sub Age7 {
	my($a) = @_;
	return $a  if miss($a);
	return  3  if $a <= 7;
	return 12  if $a <=17;
	return 22  if $a <=27;
	return 32  if $a <=37;
	return 42  if $a <=47;
	return 52  if $a <=57;
	return 62  if $a <=67;
	return 72  if $a <=78;
	return $a;
}


# ************************************

1;


=head1 Author

=over 4

=item B<TANAKA Sigeto> <tsigeto@nik.sal.tohoku.ac.jp>

Graduate School of Arts and Letters, Tohoku University

Kawauti 27-1, Aoba Ku, Sendai, Miyagi, 980-8576 JAPAN

WWW: http://www.sal.tohoku.ac.jp/~tsigeto/

=back

=head1 Copyright

	Copyright (c) 2007 TANAKA Sigeto

You may use, duplicate, revise, or redistribute 
this script, without permission from the copyright holder.

=cut
