#!/bin/perl5.8

=head1 Name

NFRJ::NFRJ03 --- Subroutines for NFRJ03 data

	Created: 2008-05-06
	Updated: 2008-05-06: Function Cohort10() 
	Updated: 2010-09-04: Function to convert income

=head1 Usage

use NFRJ::NFRJ03

=cut

package NFRJ::NFRJ03;

use Dredu;
use NFRJ;

use Exporter ();
@ISA = qw(Dredu Exporter);
@EXPORT = qw( income_10000yen %income_10000yen Eduyear %eduyear );
@EXPORT_OK = qw( );


# ************************************
#  Declare Constants and Global variables
# ************************************

=head1 Global Variables

=head2 

=cut


# ************************************
# Methods
# ************************************

=head1 Exported Subroutines

=cut

=head2 Age_class ($x) - Classify age by the given interval
		Argument $x: Interval Year
		Return: The lower limit of the range

=cut

sub Age_class {
	my ( $self, $x ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	my $a = $self->Value('Age') ;
	return $a  if miss($a);
	28 +( $x * int( ($a - 28) / $x ) ) ;
}

=head1 Exported Subroutines

=head2 Cohort10 - Birth Cohort (10-year interval)
		Argument: void

=cut

sub Cohort10 {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	my $born_ad = Era_year ( 2, $self->Value('R2Y') );

	return $born_ad  if miss($born_ad);

	1926 +( 10 * int( ($born_ad - 1926)/10 ) ) ;
}

=head2 Income_10000yen($x) - Convert income

	$x: SSM income code

=cut

%income_10000yen =(
	  1=> [    0 ,     0 ] ,
	  2=> [    0 ,   100 ] ,
	  3=> [  100 ,   200 ] ,
	  4=> [  200 ,   300 ] ,
	  5=> [  300 ,   400 ] ,
	  6=> [  400 ,   500 ] ,
	  7=> [  500 ,   600 ] ,
	  8=> [  600 ,   700 ] ,
	  9=> [  700 ,   800 ] ,
	 10=> [  800 ,   900 ] ,
	 11=> [  900 ,  1000 ] ,
	 12=> [ 1000 ,  1100 ] ,
	 13=> [ 1100 ,  1200 ] ,
	 14=> [ 1200 ,  1300 ] ,
	 15=> [ 1300 ,  1400 ] ,
	 16=> [ 1400 ,  1500 ] ,
	 17=> [ 1500 ,  1600 ] ,
	 18=> [ 1600 ,  1700 ] 
);

# To convert income
sub income_10000yen {
	my $x = @_[0];
	return ($x, $x)  if miss($x);
	
	if( exists $income_10000yen{$x} ){
		return ( $income_10000yen{$x}[0] , $income_10000yen{$x}[1] ) ;
	}
	else {
		warn( "Illegal value for income: $x\n" );
		( Missval( 'BLANK' ), Missval( 'BLANK' ) ) ;
	}
}


=head2 Eduyear($e) - Return duration of standard school education

	$e: code for school level

=cut

%eduyear = (
	1,	 9,	# Compulsory education
	2,	12,	# High-school
	3,	12,	# professional schools for high-school graduates
	4,	14,	# Junior collage (2-year)
	5,	16,	# University (4-year)
	6,	18,	# Graduate School (assuming Master = 2-year)
#	7,	Missval('NA'),	# Misc. answer
	8,	0,
) ;

sub Eduyear {
	return $eduyear{$_[0]} if defined $eduyear{$_[0]} ;
	return Missval('NA')  if 7==$_[0] ;
	return $_[0]  if miss($_[0]) ;
	warn ( "Invalid education code: $_[0]\n" );
	undef;
}



# ************************************

1;


=head1 Author

=over 4

=item B<TANAKA Sigeto> <tsigeto@nik.sal.tohoku.ac.jp>

Graduate School of Arts and Letters, Tohoku University

Kawauti 27-1, Aoba Ku, Sendai, Miyagi, 980-8576 JAPAN

WWW: http://www.sal.tohoku.ac.jp/~tsigeto/

=back

=head1 Copyright

	Copyright (c) 2007 TANAKA Sigeto

You may use, duplicate, revise, or redistribute 
this script, without permission from the copyright holder.

=cut
