#!/bin/perl5.8

=head1 Name

NFRJ::NFRJ03 --- Subroutines for NFRJ03 data

	Created: 2010-03-05
	Updated: 2010-03-05: 
	Updated: 2010-09-07: Income Function

=head1 Usage

use NFRJ::NFRJ08

=cut

package NFRJ::NFRJ08;

use Dredu;
use NFRJ;

use Exporter ();
@ISA = qw(Dredu Exporter);
@EXPORT = qw( Income_10000yen income_10000yen  %income_10000yen Eduyear %eduyear );
@EXPORT_OK = qw( );


# ************************************
#  Declare Constants and Global variables
# ************************************

=head1 Global Variables

=head2 

=cut


# ************************************
# Methods
# ************************************

=head1 Exported Subroutines

=cut

=head2 household() - Return the array for household members ($R20S1_01 .. )

	Return[0]    : number of the household members (=R20)
	Return[1..19]: 0 or 1 for each relation

=cut


sub household {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	my @r =( $self -> Value( 'R20' ) );
	my $q = 0;
	foreach $q(1..19) {
		push @r , $self -> Value( sprintf "R20S1_%02d" , $q );
	}
	@r;
}

=head2 Id() - Identification Number: "80000002" for example

=cut

sub Id {
	($self) = shift;
	return sprintf '8%02d%03d%02d' , $main::RSIKYOKU, $main::RCHITEN, $main::RTAISYO ;
}



=head2 Age_class ($x) - Classify age by the given interval
		Argument $x: Interval Year
		Return: The lower limit of the range

=cut

sub Age_class {
	my ( $self, $x ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	my $a = $self->Value('Age') ;
	return $a  if miss($a);
	28 +( $x * int( ($a - 28) / $x ) ) ;
}

=head1 Exported Subroutines

=head2 Cohort - Birth Cohort (each year in A.D.)
		Argument: void

=cut

sub Cohort {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	Era_year ( 2, $self->Value('R2Y') );
}

=head1 Exported Subroutines

=head2 Cohort10 - Birth Cohort (10-year interval)
		Argument: void

=cut

sub Cohort10 {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	my $born_ad = Era_year ( 2, $self->Value('R2Y') );

	return $born_ad  if miss($born_ad);

	1926 +( 10 * int( ($born_ad - 1926)/10 ) ) ;
}

=head2 Income_10000yen($x) - Convert income

	$x: NFRJ08 income code (1..19)

=cut

%income_10000yen =(
	  1=> 0,
	  2=>   0 + 50,
	  3=>  100 + 15,
	  4=>  130 + 35 ,
	  5=>  200 + 50,
	  6=>  300 + 50,
	  7=>  400 + 50,
	  8=>  500 + 50 ,
	  9=>  600 + 50 ,
	 10=>  700 + 50 ,
	 11=>  800 + 50 ,
	 12=>  900 + 50 ,
	 13=> 1000 + 50 ,
	 14=> 1100 + 50 ,
	 15=> 1200 + 50 ,
	 16=> 1300 + 50 ,
	 17=> 1400 + 50 ,
	 18=> 1500 + 50 ,
	 19=> 1600 + 50
);

%income_10000yen2 =(
	  1=> [    0,     0 ], 
	  2=> [    0,   100 ],
	  3=> [  100,   130  ],
	  4=> [  130 ,  200 ],
	  5=> [  200,   300 ],
	  6=> [  300,   400 ],
	  7=> [  400,   500  ],
	  8=> [  500 ,  600  ],
	  9=> [  600 ,  700  ],
	 10=> [  700 ,  800  ],
	 11=> [  800 ,  900  ],
	 12=> [  900 , 1000  ],
	 13=> [ 1000 , 1100  ],
	 14=> [ 1100 , 1200  ],
	 15=> [ 1200 , 1300  ],
	 16=> [ 1300 , 1400  ],
	 17=> [ 1400 , 1500  ],
	 18=> [ 1500 , 1600  ],
	 19=> [ 1600 , 1700  ],
);


# To convert income
sub Income_10000yen {
	my $x = @_[0];
	return $x if miss($x);
	
	if( exists $income_10000yen{$x} ){
		return $income_10000yen{$x};
	}
	else {
		warn( "Illegal value for income: $x\n" );
		Missval( 'BLANK' );
	}
}

# To convert income
sub income_10000yen {
	my $x = @_[0];
	return ( $x, $x ) if miss($x);
	
	if( exists  $income_10000yen2{$x} ){
		return @{$income_10000yen2{$x} };
	}
	else {
		warn( "Illegal value for income: $x\n" );
		
		return ( Missval( 'BLANK' ), Missval( 'BLANK' ) );
	}
}



=head2 Eduyear($e) - Return duration of standard school education

	$e: code for school level

=cut

%eduyear = (
	1,	 9,	# Compulsory education
	2,	12,	# High-school
	3,	12,	# professional schools for high-school graduates
	4,	14,	# Junior collage (2-year)
	5,	16,	# University (4-year)
	6,	18,	# Graduate School (assuming Master = 2-year)
#	7,	Missval('NA'),	# Misc. answer
	8,	0,
) ;

sub Eduyear {
	return $eduyear{$_[0]} if defined $eduyear{$_[0]} ;
	return Missval('NA')  if 7==$_[0] ;
	return $_[0]  if miss($_[0]) ;
	warn ( "Invalid education code: $_[0]\n" );
	undef;
}


# ************************************

1;


=head1 Author

=over 4

=item B<TANAKA Sigeto> <tsigeto@nik.sal.tohoku.ac.jp>

Graduate School of Arts and Letters, Tohoku University

Kawauti 27-1, Aoba Ku, Sendai, Miyagi, 980-8576 JAPAN

WWW: http://www.sal.tohoku.ac.jp/~tsigeto/

=back

=head1 Copyright

	Copyright (c) 2010 TANAKA Sigeto

You may use, duplicate, revise, or redistribute 
this script, without permission from the copyright holder.

=cut
