#!/bin/perl5.8

=head1 Name

NFRJ::NFRJ98 --- Subroutines for NFRJ98 data

	Created: 2008-05-06
	Updated: 2008-05-06: Function Cohort10() 
	Updated: 2010-06-28: Function Eduyear($e), Method for income
	Updated: 2010-09-06: Function for income

=head1 Usage

use NFRJ::NFRJ98

=cut

package NFRJ::NFRJ98;

use Dredu;
use NFRJ;

use Exporter ();
@ISA = qw(Dredu Exporter);
@EXPORT = qw( Eduyear );
@EXPORT_OK = qw( );


# ************************************
#  Declare Constants and Global variables
# ************************************

=head1 Global Variables

=head2 

=cut


# ************************************
# Methods
# ************************************

=head1 Methods

=head2 Age_class ($x) - Classify age by the given interval
		Argument $x: Interval Year
		Return: The lower limit of the range

=cut

sub Age_class {
	my ( $self, $x ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	my $a = $self->Value('Age') ;
	return $a  if miss($a);
	28 +( $x * int( ($a - 28) / $x ) ) ;
}


=head2 Cohort - Birth Cohort (A.D.)
		Argument: void

=cut

sub Cohort {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	Era_year_t( $self->values('Q02G', 'Q02Y') );
}

=head2 Cohort10 - Birth Cohort (10-year interval)
		Argument: void

=cut

sub Cohort10 {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $data.")  unless ref($self);
	my $born_ad = $self->Cohort;
	return $born_ad  if miss($born_ad);
	1921 +( 10 * int( ($born_ad - 1921)/10 ) ) ;
}

=head2 Household_income_10000yen - Convert income in metric (in 10000 yen)

=cut

=head2 Personal_income_10000yen - Convert income in metric (in 10000 yen)

=cut

%pinc_10000yen =(
	  1=> 0,
	  2=>    0 + 50,
	  3=>  100 + 15,
	  4=>  130 + 35, 
	  5=>  200 +100,
	  6=>  400 +100,
	  7=>  600 +100,
	  8=>  800 +100 ,
	  9=> 1000 +100 ,
	 10=> 1200 +100 ,
#	 99=> Missval('NA'),
);

%pinc_10000yen2 =(
	  1=> [    0,    0 ] ,
	  2=> [    0,  100 ],
	  3=> [  100,  130 ],
	  4=> [  130,  200 ] ,
	  5=> [  200,  400 ],
	  6=> [  400,  600 ],
	  7=> [  600,  800 ],
	  8=> [  800, 1000 ],
	  9=> [ 1000, 1200 ],
	 10=> [ 1200, 1400 ] ,
);

# To convert income
sub Personal_income_10000yen {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $self.")  unless ref($self);
	
	my $x = $self -> Value( 'Q10' ) ;
	return $x if miss($x);

	if( exists $pinc_10000yen{$x} ){
		return $pinc_10000yen{$x};
	}
	else {
		warn( "Illegal value for personal income: $x\n" );
		return Missval( 'BLANK' );
	}
}

# To convert income
sub personal_income_10000yen {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $self.")  unless ref($self);
	
	my $x = $self -> Value( 'Q10' ) ;
	return ( $x, $x ) if miss($x);

	if( exists $pinc_10000yen2{$x} ){
		return @{$pinc_10000yen2{$x}};
	}
	else {
		warn( "Illegal value for personal income: $x\n" );
		return Missval( 'BLANK' );
	}
}

%hinc_10000yen =(
	  1=>   0,
	  2=>   0 ,
	  3=>  100,
	  4=>  200,
	  5=>  400,
	  6=>  600,
	  7=>  800,
	  8=> 1000,
	  9=> 1200,
);

%hinc_10000yen2 =(
	  1=> [    0,     0] , 
	  2=> [    0,   100] ,
	  3=> [  100,   200] ,
	  4=> [  200,   400] ,
	  5=> [  400,   600] ,
	  6=> [  600,   800] ,
	  7=> [  800,  1000] ,
	  8=> [ 1000,  1200] ,
	  9=> [ 1200,  1400]
);

# To convert income
sub Household_income_10000yen {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $self.")  unless ref($self);
	
	my $x = $self -> Value( 'Q15' ) ;
	return $x if miss($x);
	return Missval('NA') if 10==$x;

	if( exists $hinc_10000yen{$x} ){
		return $hinc_10000yen{$x};
	}
	else {
		warn( "Illegal value for household income: $x\n" );
		return Missval( 'BLANK' );
	}
}
# To convert income
sub household_income_10000yen {
	my ( $self, @a ) = @_;
	die ( "This is an instance method, not for $self.")  unless ref($self);
	
	my $x = $self -> Value( 'Q15' ) ;
	return ( $x, $x ) if miss($x);
	return ( Missval('NA'), Missval('NA') ) if 10==$x;

	if( exists $hinc_10000yen2{$x} ){
		return @{ $hinc_10000yen2{$x} };
	}
	else {
		warn( "Illegal value for household income: $x\n" );
		return ( Missval( 'BLANK' ), Missval( 'BLANK' ) );
	}
}


=head2 Eduyear($e) - Return duration of standard school education

	$e: code for school level

=cut

%eduyear = (
	1,	 9,	# Compulsory education
	2,	12,	# High-school
	3,	12,	# professional schools for high-school graduates
	4,	14,	# Junior collage (2-year)
	5,	16,	# University (4-year)
#	6,	Missval('BLANK'),	# Misc. answer
#	9,	Missval('NA'),	# No answer
) ;

sub Eduyear {
	return $_[0]  if miss($_[0]) ;
	return Missval('BLANK')  if 6==$_[0] ;
	unless(exists $eduyear{$_[0]}) {
		warn ( "Invalid education code: $_[0]\n" );
		return undef;
	}
	Recode( $_[0], %eduyear ) ;
}



# ************************************

1;


=head1 Author

=over 4

=item B<TANAKA Sigeto> <tsigeto@nik.sal.tohoku.ac.jp>

Graduate School of Arts and Letters, Tohoku University

Kawauti 27-1, Aoba Ku, Sendai, Miyagi, 980-8576 JAPAN

WWW: http://www.sal.tohoku.ac.jp/~tsigeto/

=back

=head1 Copyright

	Copyright (c) 2007 TANAKA Sigeto

You may use, duplicate, revise, or redistribute 
this script, without permission from the copyright holder.

=cut
