#!/usr/local/bin/perl
########################################################
# NFRJ03 (2004) Data Reduction: preprocess to make a binary file
# 2007/11/23
########################################################

my $start = time;

use Dredu;

$data = Dredu->new;

$data->fs ("\t");


########################################################
#	Configuration
########################################################

$, = " ";

	# Only integer
my $TEMPLATE = 's*' ;
my $UNIT = 2 ;

	# File from SSJDA
my $DATAFILE = '0517.dat';
my $BINOUT = 'nfrj03.bin' ;

my %MISS = (
	'NA' , 		-32767,
	'OUT' , 	-32766,
	'BLANK' ,	-32765,
	'GHOST' ,	-32764,
	'YET' , 	-32763,
) ;


print "\n\n[miss]\n" ;
foreach( keys %MISS ){
	print "$_\t$MISS{$_}\n" ;
}

$data -> miss(%MISS);

########################################################
#	Variable names (from the first line)
########################################################

print "\n\n[var]\n" ;

my $head = $data -> datafile( $DATAFILE, 1 ) ;
chomp $head;
$head =~ tr/a-z/A-Z/;
my @Var = split( $data->fs , $head );

$data -> variables(@Var);

print join( "\n", @Var );

# Aliases
print <<'EOF';


[alias]
R1	Sex
R2A	Age
EOF

########################################################
#	Set missing values (from lines below __END__)
########################################################

my %Missval;
my %miss_var;

while( <DATA> ){
		# ignore empty lines
	next	if( /^\s*$/ ) ;

	chomp;

	if(  /^\s*(\w+)/ ) {
		my( $name, $out, $na ) = split(/\t/) ;

			# Upcase the variable name
		$name =~ tr/a-z/A-Z/;

		$out =~ s/^\s*$//;
		$na=~ s/^\s*$//;
		$Missval{$name}{OUT} = $out;
		$Missval{$name}{NA}= $na;

		push @{$miss_var{$out}{$na}} , $name;
	} else {
		die( "Wrong Statement: $_" ) ;
	}
}

print "\n\n[input]\n" ;

print "nvar\t" . scalar(@Var) ;

my ($k1, $k2);
foreach $k1 ( keys %miss_var ){
	foreach $k2 (keys %{$miss_var{$k1}} ){
		print "\n(OUT,NA)=($k1,$k2)\t", @{$miss_var{$k1}{$k2}};
	}
}

########################################################
# Read data
########################################################

open( BINOUT, ">$BINOUT" ) || die( "Cannot open file $BINOUT." );
binmode( BINOUT );

my $N=0;
MAINLOOP: while( $data->read_text ){
	++$N;
	printf STDERR "$N\r" ;

		# Check!
	foreach( $data->values ){
		s/^\s+$//;
		/\d +$/ && die( "Value end with space ($N)." ) ;
	}

		# Assign missing values
	foreach( @Var ){
		if(    $data->Value($_) =~ /^\s*$/ )        {
			$data -> Value( $_, $MISS{BLANK} ) ;
		}
		elsif( $Missval{$_}{OUT} && $data->Value($_) == $Missval{$_}{OUT} ){
			$data -> Value( $_, $MISS{OUT} ) ;
		}
		elsif( $Missval{$_}{NA} && $data->Value($_) == $Missval{$_}{NA}){
			$data -> Value( $_, $MISS{NA} ) ;
		}
	}

	print STDERR $data->values if grep( / / , $data->values );

	print BINOUT pack( $TEMPLATE , $data->values  ) ;
}
close( BINOUT );

print "\n\n[output]\n" ;
print "template\t$TEMPLATE" ;
print "\nrecordsize\t" , $UNIT*@Var ;
print "\nN\t" , $N ;
print "\nnvar\t" , scalar(@Var) ;
print "\nfilename\t" , $BINOUT;
my $filesize = $UNIT*$N*@Var;
print "\nfilesize\t", $filesize;
print "\n\nsec\t" , time()-$start;

my $realfilesize = (-s $BINOUT);
( $filesize ==  $realfilesize) || die( "Filesize of $BINOUT ($filesize:$realfilesize) missmatch." ) ;

__END__	# Varable name, Missing by out-of-focus, Missing by DKNA:  for input from <DATA>
NO		
RCHOUSAS		
DISTRICT		
RKIBO		
RDID		
R1		
R2Y		
R2M		
R2A		
R3	8888	9999
..............
